---
obj: application
website: https://www.portainer.io/
repo: https://github.com/portainer/portainer
---
# Portainer
Portainer is an open-source container management tool designed to simplify the deployment, management, and monitoring of [Docker](../../tools/Docker.md) containers. With its user-friendly interface and robust feature set, Portainer makes it easy for both beginners and experienced users to interact with [Docker](../../tools/Docker.md) and containerized applications.

## Features
### 1. **Intuitive Web Interface:**
- Portainer provides a web-based user interface that allows users to manage Docker containers, images, volumes, and networks with ease.
### 2. **Multi-Platform Support:**
- Portainer supports various [Docker](../../tools/Docker.md) installations, including Docker Desktop, Docker Swarm, and Kubernetes, making it a versatile choice for managing containers across different environments.
### 3. **User Authentication and Role-Based Access Control (RBAC):**
- Securely manage access to [Docker](../../tools/Docker.md) resources by implementing user authentication and RBAC. Define user roles and permissions to control who can perform specific actions.
### 4. **App Templates and Stack Deployment:**
- Portainer simplifies the deployment of applications by providing app templates. Users can deploy stacks, which are groups of interconnected services, with just a few clicks.
### 5. **Container Lifecycle Management:**
- Start, stop, restart, and remove containers effortlessly using the Portainer interface. Monitor container health and resource usage in real-time.
### 6. **Image Management:**
- Browse, pull, and manage [Docker](../../tools/Docker.md) images from Docker Hub or other registries. Portainer makes it easy to update images and inspect image details.
### 7. **Volume and Network Management:**
- Create and manage [Docker](../../tools/Docker.md) volumes and networks through the Portainer interface. Configure network settings and attach volumes to containers seamlessly.
### 8. **Endpoint Management:**
- Portainer supports the management of multiple [Docker](../../tools/Docker.md) endpoints from a single Portainer instance, providing a centralized point of control for distributed environments.

## Usage
### 1. **Container Management:**
- View, start, stop, restart, and remove containers from the Portainer dashboard. Access detailed information about each container, including logs and resource usage.
### 2. **Image Management:**
- Browse and pull [Docker](../../tools/Docker.md) images from registries. Keep images up-to-date and inspect image details, such as layers and tags.
### 3. **Volume and Network Management:**
- Create and manage [Docker](../../tools/Docker.md) volumes and networks. Configure volume bindings and network settings for containers.
### 4. **Application Deployment:**
- Deploy applications using the Stacks feature. Choose from pre-configured app templates or define your own [Docker Compose](../../tools/Docker%20Compose.md) files for customized deployments.
### 5. **Monitoring and Health Checks:**
- Monitor the health of containers and receive alerts for issues. Utilize Portainer's health check features to ensure the reliability of deployed services.
### 6. **Multi-Endpoint Management:**
- Manage [Docker](../../tools/Docker.md) endpoints from different locations using a single Portainer instance. Switch between environments to control resources across various [Docker](../../tools/Docker.md) installations.

## Docker Compose
```yaml
version: '3.3'

services:
    portainer-ce:
        ports:
            - '9010:9000' # Web UI
        restart: always
        volumes:
            - '/var/run/docker.sock:/var/run/docker.sock'
            - './data:/data'
        image: portainer/portainer-ce
```